@@ -10,8 +10,9 @@ from . import command
 from . import my_trigger as tr
 from .config import DATA_PATH, config
 from .rss_class import Rss
+from .utils import send_message_to_admin
 
-VERSION = "2.6.7"
+VERSION = "2.6.8"
 __plugin_meta__ = PluginMetadata(
     name="ELF_RSS",
     description="QQ机器人 RSS订阅 插件，订阅源建议选择 RSSHub",
@@ -46,15 +47,9 @@ async def start(bot: Bot) -> None:
 
     rss_list = Rss.read_rss()  # 读取list
     if not rss_list:
-        await bot.send_private_msg(
-            user_id=int(list(config.superusers)[0]),
-            message=f"第一次启动，你还没有订阅，记得添加哟！\n{boot_message}",
-        )
+        await send_message_to_admin(f"第一次启动，你还没有订阅，记得添加哟！\n{boot_message}", bot)
         logger.info("第一次启动，你还没有订阅，记得添加哟！")
-    await bot.send_private_msg(
-        user_id=int(list(config.superusers)[0]),
-        message=f"ELF_RSS 订阅器启动成功！\n{boot_message}",
-    )
+    await send_message_to_admin(f"ELF_RSS 订阅器启动成功！\n{boot_message}", bot)
     logger.info("ELF_RSS 订阅器启动成功！")
     # 创建检查更新任务
     await asyncio.gather(*[tr.add_job(rss) for rss in rss_list if not rss.stop])
