@@ -1,5 +1,7 @@
 import re
-from typing import Any, List, Optional
+from contextlib import suppress
+from copy import deepcopy
+from typing import Any, List, Match, Optional
 
 from nonebot import on_command
 from nonebot.adapters.onebot.v11 import GroupMessageEvent, Message, MessageEvent
@@ -15,6 +17,7 @@ from .. import my_trigger as tr
 from ..config import DATA_PATH
 from ..permission import GUILD_SUPERUSER
 from ..rss_class import Rss
+from ..utils import regex_validate
 
 RSS_CHANGE = on_command(
     "change",
@@ -45,6 +48,25 @@ def handle_property(value: str, property_list: List[Any]) -> List[Any]:
     return list(dict.fromkeys(value_list))
 
 
+# 处理类型为正则表达式的订阅参数
+def handle_regex_property(value: str, old_value: str) -> Optional[str]:
+    result = None
+    if not value:
+        result = None
+    elif value.startswith("+"):
+        result = f"{old_value}|{value.lstrip('+')}" if old_value else value.lstrip("+")
+    elif value.startswith("-"):
+        if regex_list := old_value.split("|"):
+            with suppress(ValueError):
+                regex_list.remove(value.lstrip("-"))
+            result = "|".join(regex_list) if regex_list else None
+    else:
+        result = value
+    if isinstance(result, str) and not regex_validate(result):
+        result = None
+    return result
+
+
 attribute_dict = {
     "name": "name",
     "url": "url",
@@ -110,10 +132,11 @@ def handle_change_list(
         value_to_change = bool(int(value_to_change))  # type:ignore
         if key_to_change == "stop" and not value_to_change and rss.error_count > 0:
             rss.error_count = 0
-    elif (
-        key_to_change in {"downkey", "wkey", "blackkey", "bkey", "ppk"}
-        and len(value_to_change.strip()) == 0
-    ):
+    elif key_to_change in {"downkey", "wkey", "blackkey", "bkey"}:
+        value_to_change = handle_regex_property(
+            value_to_change, getattr(rss, attribute_dict[key_to_change])
+        )  # type:ignore
+    elif key_to_change == "ppk" and not value_to_change:
         value_to_change = None  # type:ignore
     elif key_to_change == "img_num":
         value_to_change = int(value_to_change)  # type:ignore
@@ -204,16 +227,21 @@ async def handle_rss_change(
         await RSS_CHANGE.finish("❌ 禁止将多个订阅批量改名！会因为名称相同起冲突！")
 
     # 参数特殊处理：正文待移除内容
-    change_list = handle_rm_list(rss_list, change_info)
+    rm_list_exist = re.search("rm_list='.+'", change_info)
+    change_list = handle_rm_list(rss_list, change_info, rm_list_exist)
 
-    separator = "\n----------------------\n"
-    rss_msg_list = await batch_change_rss(
-        change_list, group_id, guild_channel_id, rss_list
+    changed_rss_list = await batch_change_rss(
+        change_list, group_id, guild_channel_id, rss_list, rm_list_exist
     )
-    result_msg = (
-        f"修改了 {len(rss_msg_list)} 条订阅：{separator}{separator.join(rss_msg_list)}"
-    )
-    await RSS_CHANGE.finish(f"👏 修改成功\n{result_msg}")
+    # 隐私考虑，不展示除当前群组或频道外的群组、频道和QQ
+    rss_msg_list = [
+        str(rss.hide_some_infos(group_id, guild_channel_id)) for rss in changed_rss_list
+    ]
+    result_msg = f"👏 修改了 {len(rss_msg_list)} 条订阅"
+    if rss_msg_list:
+        separator = "\n----------------------\n"
+        result_msg += separator + separator.join(rss_msg_list)
+    await RSS_CHANGE.finish(result_msg)
 
 
 async def batch_change_rss(
@@ -221,9 +249,11 @@ async def batch_change_rss(
     group_id: Optional[int],
     guild_channel_id: Optional[str],
     rss_list: List[Rss],
-) -> List[str]:
-    rss_msg_list = []
+    rm_list_exist: Optional[Match[str]] = None,
+) -> List[Rss]:
+    changed_rss_list = []
     for rss in rss_list:
+        new_rss = deepcopy(rss)
         rss_name = rss.name
         for change_dict in change_list:
             key_to_change, value_to_change = change_dict.split("=", 1)
@@ -235,31 +265,41 @@ async def batch_change_rss(
                     or value_to_change == "or"
                 ):
                     await RSS_CHANGE.finish(f"❌ 去重模式参数错误！\n{change_dict}")
+                elif key_to_change in {
+                    "downkey",
+                    "wkey",
+                    "blackkey",
+                    "bkey",
+                } and not regex_validate(value_to_change.lstrip("+-")):
+                    await RSS_CHANGE.finish(f"❌ 正则表达式错误！\n{change_dict}")
+                elif key_to_change == "ppk" and not regex_validate(value_to_change):
+                    await RSS_CHANGE.finish(f"❌ 正则表达式错误！\n{change_dict}")
                 handle_change_list(
-                    rss, key_to_change, value_to_change, group_id, guild_channel_id
+                    new_rss, key_to_change, value_to_change, group_id, guild_channel_id
                 )
             else:
                 await RSS_CHANGE.finish(f"❌ 参数错误！\n{change_dict}")
 
+        if new_rss.__dict__ == rss.__dict__ and not rm_list_exist:
+            continue
+        changed_rss_list.append(new_rss)
         # 参数解析完毕，写入
-        rss.upsert(rss_name)
+        new_rss.upsert(rss_name)
 
         # 加入定时任务
-        if not rss.stop:
-            await tr.add_job(rss)
-        else:
-            tr.delete_job(rss)
+        if not new_rss.stop:
+            await tr.add_job(new_rss)
+        elif not rss.stop:
+            tr.delete_job(new_rss)
             logger.info(f"{rss_name} 已停止更新")
 
-        # 隐私考虑，不展示除当前群组或频道外的群组、频道和QQ
-        rss_msg = str(rss.hide_some_infos(group_id, guild_channel_id))
-        rss_msg_list.append(rss_msg)
-    return rss_msg_list
+    return changed_rss_list
 
 
 # 参数特殊处理：正文待移除内容
-def handle_rm_list(rss_list: List[Rss], change_info: str) -> List[str]:
-    rm_list_exist = re.search(" rm_list='.+'", change_info)
+def handle_rm_list(
+    rss_list: List[Rss], change_info: str, rm_list_exist: Optional[Match[str]] = None
+) -> List[str]:
     rm_list = None
 
     if rm_list_exist:
@@ -271,10 +311,10 @@ def handle_rm_list(rss_list: List[Rss], change_info: str) -> List[str]:
         for rss in rss_list:
             if len(rm_list) == 1 and rm_list[0] == "-1":
                 setattr(rss, "content_to_remove", None)
-            else:
-                setattr(rss, "content_to_remove", rm_list)
+            elif valid_rm_list := [i for i in rm_list if regex_validate(i)]:
+                setattr(rss, "content_to_remove", valid_rm_list)
 
-    change_list = change_info.split(" ")
+    change_list = [i.strip() for i in change_info.split(" ")]
     # 去掉订阅名
     change_list.pop(0)
 
